==> ui-0.2.43.tgz: package/lib/cjs/Chip/Chip.styled.js <==
"use strict";

var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.Text = exports.DSChipWrapper = exports.CloseButtonWrapper = void 0;
var _base = _interopRequireDefault(require("@emotion/styled/base"));
var _react = require("@emotion/react");
var _foundations = require("../@foundations");
function _EMOTION_STRINGIFIED_CSS_ERROR__() { return "You have tried to stringify object returned from `css` function. It isn't supposed to be used directly (e.g. as value of the `className` prop), but rather handed to emotion so it can handle it (e.g. as value of `css` prop)."; }
const DSChipWrapper = /*#__PURE__*/(0, _base.default)("div", process.env.NODE_ENV === "production" ? {
  target: "e4ie90c2"
} : {
  target: "e4ie90c2",
  label: "DSChipWrapper"
})(process.env.NODE_ENV === "production" ? {
  name: "s5xdrg",
  styles: "display:flex;align-items:center"
} : {
  name: "s5xdrg",
  styles: "display:flex;align-items:center",
  map: "/*# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbIkNoaXAvQ2hpcC5zdHlsZWQuanMiXSwibmFtZXMiOltdLCJtYXBwaW5ncyI6IkFBR3dDIiwiZmlsZSI6IkNoaXAvQ2hpcC5zdHlsZWQuanMiLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgc3R5bGVkIGZyb20gJ0BlbW90aW9uL3N0eWxlZCc7XG5pbXBvcnQgeyBjc3MgfSBmcm9tICdAZW1vdGlvbi9yZWFjdCc7XG5pbXBvcnQgeyBDb2xvciB9IGZyb20gJy4uL0Bmb3VuZGF0aW9ucyc7XG5leHBvcnQgY29uc3QgRFNDaGlwV3JhcHBlciA9IHN0eWxlZC5kaXYgYFxuICBkaXNwbGF5OiBmbGV4O1xuICBhbGlnbi1pdGVtczogY2VudGVyO1xuYDtcbmV4cG9ydCBjb25zdCBDbG9zZUJ1dHRvbldyYXBwZXIgPSBzdHlsZWQuYnV0dG9uIGBcbiAgbWFyZ2luLWxlZnQ6IDRweDtcbiAgbWFyZ2luLXJpZ2h0OiAxMnB4O1xuYDtcbmV4cG9ydCBjb25zdCBUZXh0ID0gc3R5bGVkLnNwYW4gYFxuICBmb250LXNpemU6IDEycHg7XG4gIGxpbmUtaGVpZ2h0OiAxOHB4O1xuICBjb2xvcjogJHtDb2xvci5ibHVlR3JheTZ9O1xuICAkeyh7ICRjbG9zZWFibGUgfSkgPT4gISRjbG9zZWFibGUgJiZcbiAgICBjc3MgYFxuICAgICAgbWFyZ2luLXJpZ2h0OiA4cHg7XG4gICAgYH1cbmA7XG4iXX0= */",
  toString: _EMOTION_STRINGIFIED_CSS_ERROR__
});
exports.DSChipWrapper = DSChipWrapper;
const CloseButtonWrapper = /*#__PURE__*/(0, _base.default)("button", process.env.NODE_ENV === "production" ? {
  target: "e4ie90c1"
} : {
  target: "e4ie90c1",
  label: "CloseButtonWrapper"
})(process.env.NODE_ENV === "production" ? {
  name: "1t9ffh1",
  styles: "margin-left:4px;margin-right:12px"
} : {
  name: "1t9ffh1",
  styles: "margin-left:4px;margin-right:12px",
  map: "/*# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbIkNoaXAvQ2hpcC5zdHlsZWQuanMiXSwibmFtZXMiOltdLCJtYXBwaW5ncyI6IkFBT2dEIiwiZmlsZSI6IkNoaXAvQ2hpcC5zdHlsZWQuanMiLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgc3R5bGVkIGZyb20gJ0BlbW90aW9uL3N0eWxlZCc7XG5pbXBvcnQgeyBjc3MgfSBmcm9tICdAZW1vdGlvbi9yZWFjdCc7XG5pbXBvcnQgeyBDb2xvciB9IGZyb20gJy4uL0Bmb3VuZGF0aW9ucyc7XG5leHBvcnQgY29uc3QgRFNDaGlwV3JhcHBlciA9IHN0eWxlZC5kaXYgYFxuICBkaXNwbGF5OiBmbGV4O1xuICBhbGlnbi1pdGVtczogY2VudGVyO1xuYDtcbmV4cG9ydCBjb25zdCBDbG9zZUJ1dHRvbldyYXBwZXIgPSBzdHlsZWQuYnV0dG9uIGBcbiAgbWFyZ2luLWxlZnQ6IDRweDtcbiAgbWFyZ2luLXJpZ2h0OiAxMnB4O1xuYDtcbmV4cG9ydCBjb25zdCBUZXh0ID0gc3R5bGVkLnNwYW4gYFxuICBmb250LXNpemU6IDEycHg7XG4gIGxpbmUtaGVpZ2h0OiAxOHB4O1xuICBjb2xvcjogJHtDb2xvci5ibHVlR3JheTZ9O1xuICAkeyh7ICRjbG9zZWFibGUgfSkgPT4gISRjbG9zZWFibGUgJiZcbiAgICBjc3MgYFxuICAgICAgbWFyZ2luLXJpZ2h0OiA4cHg7XG4gICAgYH1cbmA7XG4iXX0= */",
  toString: _EMOTION_STRINGIFIED_CSS_ERROR__
});
exports.CloseButtonWrapper = CloseButtonWrapper;
var _ref = process.env.NODE_ENV === "production" ? {
  name: "1oaeivz",
  styles: "margin-right:8px"
} : {
  name: "rjzyl1-Text",
  styles: "margin-right:8px;label:Text;",
  map: "/*# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbIkNoaXAvQ2hpcC5zdHlsZWQuanMiXSwibmFtZXMiOltdLCJtYXBwaW5ncyI6IkFBZ0JRIiwiZmlsZSI6IkNoaXAvQ2hpcC5zdHlsZWQuanMiLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgc3R5bGVkIGZyb20gJ0BlbW90aW9uL3N0eWxlZCc7XG5pbXBvcnQgeyBjc3MgfSBmcm9tICdAZW1vdGlvbi9yZWFjdCc7XG5pbXBvcnQgeyBDb2xvciB9IGZyb20gJy4uL0Bmb3VuZGF0aW9ucyc7XG5leHBvcnQgY29uc3QgRFNDaGlwV3JhcHBlciA9IHN0eWxlZC5kaXYgYFxuICBkaXNwbGF5OiBmbGV4O1xuICBhbGlnbi1pdGVtczogY2VudGVyO1xuYDtcbmV4cG9ydCBjb25zdCBDbG9zZUJ1dHRvbldyYXBwZXIgPSBzdHlsZWQuYnV0dG9uIGBcbiAgbWFyZ2luLWxlZnQ6IDRweDtcbiAgbWFyZ2luLXJpZ2h0OiAxMnB4O1xuYDtcbmV4cG9ydCBjb25zdCBUZXh0ID0gc3R5bGVkLnNwYW4gYFxuICBmb250LXNpemU6IDEycHg7XG4gIGxpbmUtaGVpZ2h0OiAxOHB4O1xuICBjb2xvcjogJHtDb2xvci5ibHVlR3JheTZ9O1xuICAkeyh7ICRjbG9zZWFibGUgfSkgPT4gISRjbG9zZWFibGUgJiZcbiAgICBjc3MgYFxuICAgICAgbWFyZ2luLXJpZ2h0OiA4cHg7XG4gICAgYH1cbmA7XG4iXX0= */",
  toString: _EMOTION_STRINGIFIED_CSS_ERROR__
};
const Text = /*#__PURE__*/(0, _base.default)("span", process.env.NODE_ENV === "production" ? {
  target: "e4ie90c0"
} : {
  target: "e4ie90c0",
  label: "Text"
})("font-size:12px;line-height:18px;color:", _foundations.Color.blueGray6, ";", _ref2 => {
  let {
    $closeable
  } = _ref2;
  return !$closeable && _ref;
}, ";" + (process.env.NODE_ENV === "production" ? "" : "/*# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbIkNoaXAvQ2hpcC5zdHlsZWQuanMiXSwibmFtZXMiOltdLCJtYXBwaW5ncyI6IkFBV2dDIiwiZmlsZSI6IkNoaXAvQ2hpcC5zdHlsZWQuanMiLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgc3R5bGVkIGZyb20gJ0BlbW90aW9uL3N0eWxlZCc7XG5pbXBvcnQgeyBjc3MgfSBmcm9tICdAZW1vdGlvbi9yZWFjdCc7XG5pbXBvcnQgeyBDb2xvciB9IGZyb20gJy4uL0Bmb3VuZGF0aW9ucyc7XG5leHBvcnQgY29uc3QgRFNDaGlwV3JhcHBlciA9IHN0eWxlZC5kaXYgYFxuICBkaXNwbGF5OiBmbGV4O1xuICBhbGlnbi1pdGVtczogY2VudGVyO1xuYDtcbmV4cG9ydCBjb25zdCBDbG9zZUJ1dHRvbldyYXBwZXIgPSBzdHlsZWQuYnV0dG9uIGBcbiAgbWFyZ2luLWxlZnQ6IDRweDtcbiAgbWFyZ2luLXJpZ2h0OiAxMnB4O1xuYDtcbmV4cG9ydCBjb25zdCBUZXh0ID0gc3R5bGVkLnNwYW4gYFxuICBmb250LXNpemU6IDEycHg7XG4gIGxpbmUtaGVpZ2h0OiAxOHB4O1xuICBjb2xvcjogJHtDb2xvci5ibHVlR3JheTZ9O1xuICAkeyh7ICRjbG9zZWFibGUgfSkgPT4gISRjbG9zZWFibGUgJiZcbiAgICBjc3MgYFxuICAgICAgbWFyZ2luLXJpZ2h0OiA4cHg7XG4gICAgYH1cbmA7XG4iXX0= */"));
exports.Text = Text;

==> ui-0.2.52.tgz: package/lib/cjs/Chip/Chip.styled.js <==
"use strict";

var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.Text = exports.DSChipWrapper = exports.CloseButtonWrapper = void 0;
var _base = _interopRequireDefault(require("@emotion/styled/base"));
var _react = require("@emotion/react");
var _foundations = require("../@foundations");
function _EMOTION_STRINGIFIED_CSS_ERROR__() { return "You have tried to stringify object returned from `css` function. It isn't supposed to be used directly (e.g. as value of the `className` prop), but rather handed to emotion so it can handle it (e.g. as value of `css` prop)."; }
const DSChipWrapper = exports.DSChipWrapper = /*#__PURE__*/(0, _base.default)("div", process.env.NODE_ENV === "production" ? {
  target: "e4ie90c2"
} : {
  target: "e4ie90c2",
  label: "DSChipWrapper"
})(process.env.NODE_ENV === "production" ? {
  name: "s5xdrg",
  styles: "display:flex;align-items:center"
} : {
  name: "s5xdrg",
  styles: "display:flex;align-items:center",
  map: "/*# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbIkNoaXAvQ2hpcC5zdHlsZWQuanMiXSwibmFtZXMiOltdLCJtYXBwaW5ncyI6IkFBR3dDIiwiZmlsZSI6IkNoaXAvQ2hpcC5zdHlsZWQuanMiLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgc3R5bGVkIGZyb20gJ0BlbW90aW9uL3N0eWxlZCc7XG5pbXBvcnQgeyBjc3MgfSBmcm9tICdAZW1vdGlvbi9yZWFjdCc7XG5pbXBvcnQgeyBDb2xvciB9IGZyb20gJy4uL0Bmb3VuZGF0aW9ucyc7XG5leHBvcnQgY29uc3QgRFNDaGlwV3JhcHBlciA9IHN0eWxlZC5kaXYgYFxuICBkaXNwbGF5OiBmbGV4O1xuICBhbGlnbi1pdGVtczogY2VudGVyO1xuYDtcbmV4cG9ydCBjb25zdCBDbG9zZUJ1dHRvbldyYXBwZXIgPSBzdHlsZWQuYnV0dG9uIGBcbiAgbWFyZ2luLWxlZnQ6IDRweDtcbiAgbWFyZ2luLXJpZ2h0OiAxMnB4O1xuYDtcbmV4cG9ydCBjb25zdCBUZXh0ID0gc3R5bGVkLnNwYW4gYFxuICBmb250LXNpemU6IDEycHg7XG4gIGxpbmUtaGVpZ2h0OiAxOHB4O1xuICBjb2xvcjogJHtDb2xvci5ibHVlR3JheTZ9O1xuICAkeyh7ICRjbG9zZWFibGUgfSkgPT4gISRjbG9zZWFibGUgJiZcbiAgICBjc3MgYFxuICAgICAgbWFyZ2luLXJpZ2h0OiA4cHg7XG4gICAgYH1cbmA7XG4iXX0= */",
  toString: _EMOTION_STRINGIFIED_CSS_ERROR__
});
const CloseButtonWrapper = exports.CloseButtonWrapper = /*#__PURE__*/(0, _base.default)("button", process.env.NODE_ENV === "production" ? {
  target: "e4ie90c1"
} : {
  target: "e4ie90c1",
  label: "CloseButtonWrapper"
})(process.env.NODE_ENV === "production" ? {
  name: "1t9ffh1",
  styles: "margin-left:4px;margin-right:12px"
} : {
  name: "1t9ffh1",
  styles: "margin-left:4px;margin-right:12px",
  map: "/*# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbIkNoaXAvQ2hpcC5zdHlsZWQuanMiXSwibmFtZXMiOltdLCJtYXBwaW5ncyI6IkFBT2dEIiwiZmlsZSI6IkNoaXAvQ2hpcC5zdHlsZWQuanMiLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgc3R5bGVkIGZyb20gJ0BlbW90aW9uL3N0eWxlZCc7XG5pbXBvcnQgeyBjc3MgfSBmcm9tICdAZW1vdGlvbi9yZWFjdCc7XG5pbXBvcnQgeyBDb2xvciB9IGZyb20gJy4uL0Bmb3VuZGF0aW9ucyc7XG5leHBvcnQgY29uc3QgRFNDaGlwV3JhcHBlciA9IHN0eWxlZC5kaXYgYFxuICBkaXNwbGF5OiBmbGV4O1xuICBhbGlnbi1pdGVtczogY2VudGVyO1xuYDtcbmV4cG9ydCBjb25zdCBDbG9zZUJ1dHRvbldyYXBwZXIgPSBzdHlsZWQuYnV0dG9uIGBcbiAgbWFyZ2luLWxlZnQ6IDRweDtcbiAgbWFyZ2luLXJpZ2h0OiAxMnB4O1xuYDtcbmV4cG9ydCBjb25zdCBUZXh0ID0gc3R5bGVkLnNwYW4gYFxuICBmb250LXNpemU6IDEycHg7XG4gIGxpbmUtaGVpZ2h0OiAxOHB4O1xuICBjb2xvcjogJHtDb2xvci5ibHVlR3JheTZ9O1xuICAkeyh7ICRjbG9zZWFibGUgfSkgPT4gISRjbG9zZWFibGUgJiZcbiAgICBjc3MgYFxuICAgICAgbWFyZ2luLXJpZ2h0OiA4cHg7XG4gICAgYH1cbmA7XG4iXX0= */",
  toString: _EMOTION_STRINGIFIED_CSS_ERROR__
});
var _ref = process.env.NODE_ENV === "production" ? {
  name: "1oaeivz",
  styles: "margin-right:8px"
} : {
  name: "rjzyl1-Text",
  styles: "margin-right:8px;label:Text;",
  map: "/*# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbIkNoaXAvQ2hpcC5zdHlsZWQuanMiXSwibmFtZXMiOltdLCJtYXBwaW5ncyI6IkFBZ0JRIiwiZmlsZSI6IkNoaXAvQ2hpcC5zdHlsZWQuanMiLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgc3R5bGVkIGZyb20gJ0BlbW90aW9uL3N0eWxlZCc7XG5pbXBvcnQgeyBjc3MgfSBmcm9tICdAZW1vdGlvbi9yZWFjdCc7XG5pbXBvcnQgeyBDb2xvciB9IGZyb20gJy4uL0Bmb3VuZGF0aW9ucyc7XG5leHBvcnQgY29uc3QgRFNDaGlwV3JhcHBlciA9IHN0eWxlZC5kaXYgYFxuICBkaXNwbGF5OiBmbGV4O1xuICBhbGlnbi1pdGVtczogY2VudGVyO1xuYDtcbmV4cG9ydCBjb25zdCBDbG9zZUJ1dHRvbldyYXBwZXIgPSBzdHlsZWQuYnV0dG9uIGBcbiAgbWFyZ2luLWxlZnQ6IDRweDtcbiAgbWFyZ2luLXJpZ2h0OiAxMnB4O1xuYDtcbmV4cG9ydCBjb25zdCBUZXh0ID0gc3R5bGVkLnNwYW4gYFxuICBmb250LXNpemU6IDEycHg7XG4gIGxpbmUtaGVpZ2h0OiAxOHB4O1xuICBjb2xvcjogJHtDb2xvci5ibHVlR3JheTZ9O1xuICAkeyh7ICRjbG9zZWFibGUgfSkgPT4gISRjbG9zZWFibGUgJiZcbiAgICBjc3MgYFxuICAgICAgbWFyZ2luLXJpZ2h0OiA4cHg7XG4gICAgYH1cbmA7XG4iXX0= */",
  toString: _EMOTION_STRINGIFIED_CSS_ERROR__
};
const Text = exports.Text = /*#__PURE__*/(0, _base.default)("span", process.env.NODE_ENV === "production" ? {
  target: "e4ie90c0"
} : {
  target: "e4ie90c0",
  label: "Text"
})("font-size:12px;line-height:18px;color:", _foundations.Color.blueGray6, ";", _ref2 => {
  let {
    $closeable
  } = _ref2;
  return !$closeable && _ref;
}, ";" + (process.env.NODE_ENV === "production" ? "" : "/*# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbIkNoaXAvQ2hpcC5zdHlsZWQuanMiXSwibmFtZXMiOltdLCJtYXBwaW5ncyI6IkFBV2dDIiwiZmlsZSI6IkNoaXAvQ2hpcC5zdHlsZWQuanMiLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgc3R5bGVkIGZyb20gJ0BlbW90aW9uL3N0eWxlZCc7XG5pbXBvcnQgeyBjc3MgfSBmcm9tICdAZW1vdGlvbi9yZWFjdCc7XG5pbXBvcnQgeyBDb2xvciB9IGZyb20gJy4uL0Bmb3VuZGF0aW9ucyc7XG5leHBvcnQgY29uc3QgRFNDaGlwV3JhcHBlciA9IHN0eWxlZC5kaXYgYFxuICBkaXNwbGF5OiBmbGV4O1xuICBhbGlnbi1pdGVtczogY2VudGVyO1xuYDtcbmV4cG9ydCBjb25zdCBDbG9zZUJ1dHRvbldyYXBwZXIgPSBzdHlsZWQuYnV0dG9uIGBcbiAgbWFyZ2luLWxlZnQ6IDRweDtcbiAgbWFyZ2luLXJpZ2h0OiAxMnB4O1xuYDtcbmV4cG9ydCBjb25zdCBUZXh0ID0gc3R5bGVkLnNwYW4gYFxuICBmb250LXNpemU6IDEycHg7XG4gIGxpbmUtaGVpZ2h0OiAxOHB4O1xuICBjb2xvcjogJHtDb2xvci5ibHVlR3JheTZ9O1xuICAkeyh7ICRjbG9zZWFibGUgfSkgPT4gISRjbG9zZWFibGUgJiZcbiAgICBjc3MgYFxuICAgICAgbWFyZ2luLXJpZ2h0OiA4cHg7XG4gICAgYH1cbmA7XG4iXX0= */"));
